@@ -16,6 +16,7 @@ use once_cell::sync::Lazy;
 use psl::Psl;
 use smol::prelude::*;
 
+use smol_timeout::TimeoutExt;
 use tap::Tap;
 
 use std::{
@@ -48,7 +49,7 @@ pub struct ConnectOpt {
     /// Number of local UDP ports to use per session. This works around situations where unlucky ECMP routing sends flows down a congested path even when other paths exist, by "averaging out" all the possible routes.
     pub udp_shard_count: usize,
 
-    #[structopt(long, default_value = "3")]
+    #[structopt(long, default_value = "1")]
     /// Lifetime of a single UDP port. Geph will switch to a different port within this many seconds.
     pub udp_shard_lifetime: u64,
 
@@ -479,7 +480,11 @@ async fn handle_socks5(
         )
         .await?;
     } else {
-        let conn = tunnel_manager.connect(&addr).await?;
+        let conn = tunnel_manager
+            .connect(&addr)
+            .timeout(Duration::from_secs(10))
+            .await
+            .context("open connection timeout")??;
         write_request_status(
             s5client.clone(),
             SocksV5RequestStatus::Success,
